@@ -322,7 +322,8 @@ ephy_sync_utils_get_device_name (void)
 
   g_free (name);
   /* Translators: First %s is the name of the user currently logged in on the
-   * machine. The second %s is the machine's name. */
+   * machine. The second %s is the machine's name. You can use the variables
+   * in a different order by changing them to %2$s and %1$s. */
   name = g_strdup_printf (_("%s’s GNOME Web on %s"), g_get_user_name (), g_get_host_name ());
   g_settings_set_string (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_DEVICE_NAME, name);
 
@@ -395,15 +396,15 @@ ephy_sync_utils_bookmarks_sync_is_enabled (void)
 }
 
 void
-ephy_sync_utils_set_bookmarks_sync_time (double time)
+ephy_sync_utils_set_bookmarks_sync_time (gint64 time)
 {
-  g_settings_set_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_BOOKMARKS_TIME, time);
+  g_settings_set_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_BOOKMARKS_TIME, time);
 }
 
-double
+gint64
 ephy_sync_utils_get_bookmarks_sync_time (void)
 {
-  return g_settings_get_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_BOOKMARKS_TIME);
+  return g_settings_get_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_BOOKMARKS_TIME);
 }
 
 void
@@ -425,15 +426,15 @@ ephy_sync_utils_passwords_sync_is_enabled (void)
 }
 
 void
-ephy_sync_utils_set_passwords_sync_time (double time)
+ephy_sync_utils_set_passwords_sync_time (gint64 time)
 {
-  g_settings_set_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_PASSWORDS_TIME, time);
+  g_settings_set_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_PASSWORDS_TIME, time);
 }
 
-double
+gint64
 ephy_sync_utils_get_passwords_sync_time (void)
 {
-  return g_settings_get_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_PASSWORDS_TIME);
+  return g_settings_get_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_PASSWORDS_TIME);
 }
 
 void
@@ -455,15 +456,15 @@ ephy_sync_utils_history_sync_is_enabled (void)
 }
 
 void
-ephy_sync_utils_set_history_sync_time (double time)
+ephy_sync_utils_set_history_sync_time (gint64 time)
 {
-  g_settings_set_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_HISTORY_TIME, time);
+  g_settings_set_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_HISTORY_TIME, time);
 }
 
-double
+gint64
 ephy_sync_utils_get_history_sync_time (void)
 {
-  return g_settings_get_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_HISTORY_TIME);
+  return g_settings_get_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_HISTORY_TIME);
 }
 
 void
@@ -485,13 +486,13 @@ ephy_sync_utils_open_tabs_sync_is_enabled (void)
 }
 
 void
-ephy_sync_utils_set_open_tabs_sync_time (double time)
+ephy_sync_utils_set_open_tabs_sync_time (gint64 time)
 {
-  g_settings_set_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_OPEN_TABS_TIME, time);
+  g_settings_set_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_OPEN_TABS_TIME, time);
 }
 
-double
+gint64
 ephy_sync_utils_get_open_tabs_sync_time (void)
 {
-  return g_settings_get_double (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_OPEN_TABS_TIME);
+  return g_settings_get_int64 (EPHY_SETTINGS_SYNC, EPHY_PREFS_SYNC_OPEN_TABS_TIME);
 }
