@@ -583,7 +583,7 @@ on_sync_sign_out_button_clicked (GtkWidget   *button,
 {
   EphySyncService *service = ephy_shell_get_sync_service (ephy_shell_get_default ());
 
-  ephy_sync_service_sign_out (service, TRUE);
+  ephy_sync_service_sign_out (service);
 
   /* Show Firefox Accounts iframe. */
   sync_setup_firefox_iframe (dialog);
@@ -636,10 +636,16 @@ on_sync_device_name_save_button_clicked (GtkWidget   *button,
                                          PrefsDialog *dialog)
 {
   EphySyncService *service = ephy_shell_get_sync_service (ephy_shell_get_default ());
-  const char *name;
+  const char *text;
 
-  name = gtk_entry_get_text (GTK_ENTRY (dialog->sync_device_name_entry));
-  ephy_sync_service_register_device (service, name);
+  text = gtk_entry_get_text (GTK_ENTRY (dialog->sync_device_name_entry));
+  if (!g_strcmp0 (text, "")) {
+    char *name = ephy_sync_utils_get_device_name ();
+    gtk_entry_set_text (GTK_ENTRY (dialog->sync_device_name_entry), name);
+    g_free (name);
+  } else {
+    ephy_sync_service_update_device_name (service, text);
+  }
 
   gtk_widget_set_sensitive (GTK_WIDGET (dialog->sync_device_name_entry), FALSE);
   gtk_widget_set_visible (GTK_WIDGET (dialog->sync_device_name_change_button), TRUE);
@@ -796,6 +802,44 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, on_sync_device_name_cancel_button_clicked);
 }
 
+static void
+css_file_opened_cb (GObject      *source,
+                    GAsyncResult *result,
+                    gpointer      user_data)
+{
+  gboolean ret;
+  GError *error = NULL;
+
+  ret = ephy_open_file_via_flatpak_portal_finish (result, &error);
+  if (!ret) {
+    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+      g_warning ("Failed to open CSS file: %s", error->message);
+    g_error_free (error);
+  }
+}
+
+static void
+css_file_created_cb (GObject      *source,
+                     GAsyncResult *result,
+                     gpointer      user_data)
+{
+  GFile *file = G_FILE (source);
+  GFileOutputStream *stream;
+  GError *error = NULL;
+
+  stream = g_file_create_finish (file, result, &error);
+  if (stream == NULL && !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+    g_warning ("Failed to create %s: %s", g_file_get_path (file), error->message);
+  else
+    ephy_open_file_via_flatpak_portal (g_file_get_path (file), NULL, css_file_opened_cb, NULL);
+
+  if (error != NULL)
+    g_error_free (error);
+  if (stream != NULL)
+    g_object_unref (stream);
+  g_object_unref (file);
+}
+
 static void
 css_edit_button_clicked_cb (GtkWidget   *button,
                             PrefsDialog *pd)
@@ -806,9 +850,13 @@ css_edit_button_clicked_cb (GtkWidget   *button,
                                                     USER_STYLESHEET_FILENAME,
                                                     NULL));
 
-  ephy_file_launch_handler ("text/plain", css_file,
-                            gtk_get_current_event_time ());
-  g_object_unref (css_file);
+  if (ephy_is_running_inside_flatpak ()) {
+    g_file_create_async (css_file, G_FILE_CREATE_NONE, G_PRIORITY_DEFAULT, NULL, css_file_created_cb, NULL);
+  } else {
+    ephy_file_launch_handler ("text/plain", css_file,
+                              gtk_get_current_event_time ());
+    g_object_unref (css_file);
+  }
 }
 
 static void
@@ -1372,21 +1420,16 @@ do_not_track_button_clicked_cb (GtkWidget   *button,
 {
   char **filters;
   char **new_filters;
-  char **newer_filters;
 
   filters = g_settings_get_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS);
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button))) {
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     new_filters = ephy_strv_append ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-    newer_filters = ephy_strv_append ((const char * const *)new_filters, ADBLOCK_ANNOYANCE_FILTER_URL);
-  } else {
+  else
     new_filters = ephy_strv_remove ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-    newer_filters = ephy_strv_remove ((const char * const *)new_filters, ADBLOCK_ANNOYANCE_FILTER_URL);
-  }
-  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)newer_filters);
+  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)new_filters);
 
   g_strfreev (filters);
   g_strfreev (new_filters);
-  g_strfreev (newer_filters);
 }
 
 static void
